@@ -16,8 +16,10 @@ def test_open_jpk_simple():
     loc_list = [ff for ff in jpkr.files if ff.count(p_seg)]
     name, slot, dat = jpk_data.find_column_dat(loc_list, "height (piezo)")
     properties = jpkr._get_index_segment_properties(0, 0)
-    with jpkr.arc.open(dat, "r") as fd:
-        height = jpk_data.load_dat_raw(fd, name=name, properties=properties)
+    with jpkr.get_archive() as arc:
+        with arc.open(dat, "r") as fd:
+            height = jpk_data.load_dat_raw(fd, name=name,
+                                           properties=properties)
     assert height[0] == 50.425720226584403
 
 
@@ -40,9 +42,10 @@ def test_open_jpk_conversion():
     chan_data = {}
     for column in ["force", "height (piezo)", "height (measured)"]:
         name, slot, dat = jpk_data.find_column_dat(loc_list, column)
-        with jpkr.arc.open(dat, "r") as fd:
-            chan_data[name] = jpk_data.load_dat_unit(fd, name, properties,
-                                                     slot)
+        with jpkr.get_archive() as arc:
+            with arc.open(dat, "r") as fd:
+                chan_data[name] = jpk_data.load_dat_unit(fd, name, properties,
+                                                         slot)
     assert chan_data["vDeflection"][2] == "vDeflection (Force)"
     assert chan_data["vDeflection"][1] == "N"
     assert chan_data["vDeflection"][0][0] == -5.145579192349918e-10
@@ -101,10 +104,11 @@ def test_get_single_custom_slot():
     loc_list = [ff for ff in jpkr.files if ff.count(p_seg)]
     name, slot, dat = jpk_data.find_column_dat(loc_list, "height (piezo)")
     properties = jpkr._get_index_segment_properties(0, 0)
-    with jpkr.arc.open(dat, "r") as fd:
-        data, unit, _ = jpk_data.load_dat_unit(fd, name=name,
-                                               properties=properties,
-                                               slot="nominal")
+    with jpkr.get_archive() as arc:
+        with arc.open(dat, "r") as fd:
+            data, unit, _ = jpk_data.load_dat_unit(fd, name=name,
+                                                   properties=properties,
+                                                   slot="nominal")
     assert data[0] == 4.9574279773415606e-05
 
 
@@ -126,7 +130,7 @@ def test_load_jpk():
 
 if __name__ == "__main__":
     # Run all tests
-    loc = locals()
-    for key in list(loc.keys()):
-        if key.startswith("test_") and hasattr(loc[key], "__call__"):
-            loc[key]()
+    _loc = locals()
+    for _key in list(_loc.keys()):
+        if _key.startswith("test_") and hasattr(_loc[_key], "__call__"):
+            _loc[_key]()
